/**
 * File: graph-constants.h
 * -----------------------
 * Consolidates constants shared between model and view.
 */

#pragma once
#include <cmath>

/**
 * Distance Constants: kWindowWidth, kWindowHeight, kMaxDistance, kInset
 * ---------------------------------------------------------------------
 * kWindowWidth and kWindowHeight define the width and height of the graphics
 * window, and they also dictate the largest random x and y value that can be assigned
 * to a randomly located node in a graph.  kMaxDistance is derived from kWindowWidth
 * and kWindowHeight and dictates the largest arc weight that might be present in a
 * graph that fits in the window.  kInset is the radius of the circles we use to draw
 * the nodes of a graph in the graphics window.
 */
static const int kWindowWidth = 800;
static const int kWindowHeight = 500;
static const double kMaxDistance = std::sqrt(kWindowWidth * kWindowWidth + kWindowHeight * kWindowHeight);
static const int kInset = 5;

/**
 * Duration Constant: kObserveDelay
 * --------------------------------
 * The pause time we're granted to observe the shortest path or
 * the minimal spanning tree generated by Dijkstra's or Kruskal's
 * algorithm.
 */
static const int kObserveDelay = 10000;

/**
 * Size Constants: kMinNumNodes, kMaxNumNodes
 * ------------------------------------------
 * Tracks the minimum and maximum number of nodes in
 * our randomly generated graphs.
 */
static const int kMinNumNodes = 60;
static const int kMaxNumNodes = 80;
